<p align="center">
  <a href="https://squidfunk.github.io/mkdocs-material/">
    <img src="https://raw.githubusercontent.com/squidfunk/mkdocs-material/master/.github/assets/logo.png" width="320" alt="Material for MkDocs">
  </a>
</p>

<p align="center">
  <strong>
    A 
    <a href="https://traefik.io/">Traefik Labs</a> 
    <a href="https://material.io/">Material Design</a> 
    theme for 
    <a href="https://www.mkdocs.org/">MkDocs</a>
  </strong>
</p>

## Quick start

Material for MkDocs can be installed with `pip`:

``` sh
pip install mkdocs-traefiklabs
```

Add the following line to `mkdocs.yml`:

``` yaml
theme:
  name: traefik-labs
```